@@ -6,6 +6,11 @@ use strict;
 use base qw|Jifty::DBI::Filter|;
 use DateTime                  ();
 use DateTime::Format::ISO8601 ();
+use DateTime::Format::Strptime ();
+
+use constant _time_zone => '';
+use constant _strptime  => '%Y-%m-%d %H:%M:%S';
+
 
 =head1 NAME
 
@@ -13,8 +18,9 @@ Jifty::DBI::Filter::DateTime - DateTime object wrapper around date columns
 
 =head1 DESCRIPTION
 
-This filter allow you to work with DateTime objects instead of plain
-text dates.
+This filter allow you to work with DateTime objects instead of
+plain text dates.  If the column type is "date", then the hour,
+minute, and second information is discarded when encoding.
 
 =head2 encode
 
@@ -32,9 +38,11 @@ sub encode {
 
     return unless UNIVERSAL::isa( $$value_ref, 'DateTime' );
 
-    my $format = ($self->column->type eq "date" ? "%Y-%m-%d" : "%Y-%m-%d %H:%M:%S");
-    $$value_ref = $$value_ref->strftime($format);
-
+    if (my $tz = $self->_time_zone) {
+	$$value_ref = $$value_ref->clone;
+	$$value_ref->time_zone('floating');
+    }
+    $$value_ref = $$value_ref->strftime($self->_strptime);
     return 1;
 }
 
@@ -60,7 +68,12 @@ sub decode {
 
     my $str = join('T', split ' ', $$value_ref, 2);
     my $dt = DateTime::Format::ISO8601->parse_datetime($str);
+
     if ($dt) {
+	my $tz = $self->_time_zone;
+	$dt->time_zone($tz) if $tz;
+
+        $dt->set_formatter(DateTime::Format::Strptime->new(pattern => $self->_strptime));
         $$value_ref = $dt;
     } else {
         return;
